@@ -203,12 +203,8 @@ export const FileExplorerHeaderName = styled(Typography)`
 `;
 
 export const FileTree = styled(TreeView)`
-    padding: 0px 0px 0px 10px;
     max-width: 100%;
-    height: 80%;
-    .MuiTreeItem-group {
-        margin-left: 5px;
-    }
+    height: 100%;
 `;
 
 export const FileItem = styled(TreeItem)`
@@ -216,8 +212,11 @@ export const FileItem = styled(TreeItem)`
         font-size: 14px;
         line-height: 2em;
     }
+    .MuiTreeItem-group {
+        margin-left: 10px;
+    }
     .MuiTreeItem-content {
-        padding-left: 5px;
+        // margin-left: 5px;
     }
     color: ${(props) => props.theme.palette.text.secondary};
     width: 100%;
@@ -248,11 +247,10 @@ export const WorkingPanelSplitPanel = styled(SplitPane)`
 `;
 
 export const StyledCodePanel = styled.div`
-    background-color: ${(props) => props.theme.palette.background.paper};
+    display: flex;
     flex-direction: column;
-    align-items: center;
-    // border: 1px solid ${(props) => props.theme.palette.divider};
-    // width: 30%;
+    background-color: ${(props) => props.theme.palette.background.paper};
+    // align-items: center;
     height: 100%;
     overflow: hidden;
     // overflow: auto;
@@ -260,7 +258,7 @@ export const StyledCodePanel = styled.div`
 
 export const CodeToolbar = styled.div`
     display: flex;
-    --var-height: 40px;
+    --var-height: 30px;
     height: calc(var(--var-height));
     align-items: center;
     background-color: ${(props) => props.theme.palette.grey.A200};
@@ -420,16 +418,20 @@ export const CodeEditMarker = styled.div`
     border: 2px;
 `;
 export const CodeOutputContainer = styled.div`
-    // display: flex;
+    display: flex;
+    flex-direction: column;
     padding: 0px 10px 0px 10px;
     color: ${(props) => props.theme.palette.text.secondary};
-    // flex-grow: 1;
     height: 100%;
     width: 100%;
-    max-height: 80%; //have to keep this 80% otherwise scroll to view will mess the frame up
 `;
-export const CodeOutputHeader = styled(Typography)`
-    // height: 10px;
+
+export const CodeOutputHeader = styled.div`
+    height: 30px;
+`;
+
+export const CodeOutputHeaderText = styled(Typography)`
+    // height: 30px;
     // text-decoration: underline;
     font-size: 12px;
     border-bottom-style: solid;
@@ -437,8 +439,9 @@ export const CodeOutputHeader = styled(Typography)`
 `;
 // need this compoent to make the text output respect tab character
 export const CodeOutputContent = styled.div`
-    overflow: auto;
-    max-height: 90%;
+    overflow: auto;    
+    height: 100%;
+    flex-grow: 1;
 `;
 // export const IndividualCodeOutputContent = styled.pre`
 //     margin: 0px;
@@ -453,11 +456,20 @@ export const IndividualCodeOutputContent = styled(Typography)`
     margin: 0px;
     padding: 5px 0px 5px 0px;
     overflow: auto;
-    max-height: 100%;
     font-size: 13px;
     &:hover {
         background-color: ${(props) => props.theme.palette.action.hover};
     }
+    code {
+        display: inline-block;
+        white-space: pre-wrap; /* Since CSS 2.1 */
+        white-space: -moz-pre-wrap; /* Mozilla, since 1999 */
+        white-space: -pre-wrap; /* Opera 4-6 */
+        white-space: -o-pre-wrap; /* Opera 7 */
+        max-width: 100%;
+        // word-break: break-all;
+        word-wrap: break-word;
+    }
 `;
 
 // export const ReviewButton = styled.a`
@@ -714,11 +726,16 @@ export const ResultViewContainer = styled.div`
 export const PlotContainer = styled(Paper)`
     background-color: ${(props) => props.theme.palette.background.paper};
     margin: 1px;
-    overflow: hidden;
+    overflow: auto;
     width: fit-content;
     border-color: ${(props) => (props.focused ? props.theme.palette.primary.light : null)};
     border-width: ${(props) => (props.focused ? "2px" : null)};
     margin-bottom: 8px;
+    svg {
+        width: 1000px;
+        height: 1000px;
+        overflow: scroll
+    }
 `;
 
 export const SmallVizContainer = styled(MuiTableContainer)`
