@@ -97,6 +97,8 @@ export enum StandardMimeType {
     APPLICATION_JSON = "application/json",
     APPLICATION_CNEXT = "application/cnext+json",
     APPLICATION_PLOTLY = "application/vnd.plotly.v1+json",
+    APPLICATION_JAVASCRIPT = "application/javascript",
+    APPLICATION_BOKEH = "application/vnd.bokehjs_load.v0+json",
 }
 
 export const SubContentType = StandardMimeType;
@@ -281,10 +283,17 @@ export interface IShorcutKey {
     set_ungroup: string;
 }
 
+export interface IEditorConfigs {
+    lint: boolean;
+    hover: boolean;
+    autocompletion: boolean;
+}
+
 export interface IConfigs {
     experiment_manager?: IExperimentManagerConfig;
     view_mode: ViewMode | undefined;
     shortcut_keys: IShorcutKey;
+    code_editor: IEditorConfigs;
 }
 
 export enum DFViewMode {
