@@ -1,9 +1,11 @@
+import re
 import requests
 import base64
 import collections
 import itertools
 import sys
 import traceback
+import simplejson as json
 
 from libs.message_handler import BaseMessageHandler
 from libs.message import ContentType, DFManagerCommand, SubContentType
@@ -68,6 +70,20 @@ class MessageHandler(BaseMessageHandler):
         with open(file_path, 'rb') as file:
             return file.read()
 
+    def _is_jsonable(self, obj):
+        try:
+            json.dumps(obj)
+            return True
+        except (TypeError, OverflowError):
+            return False
+
+    def _convert_to_str_if_not_jsonable(self, df):
+        for c in df.columns:
+            for r in df.index:
+                if not self._is_jsonable(df.at[r, c]):
+                    df.at[r, c] = str(df.at[r, c])
+        return df
+
     def _create_table_data(self, df_id, df):
         ''' The tableData will be the same as the original `df` except for two exceptions
             1. if column type is datatime64[ns], the data will be reformated
@@ -79,13 +95,13 @@ class MessageHandler(BaseMessageHandler):
         tableData['df_id'] = df_id
         tableData['column_names'] = list(df.columns)
 
-        ## Convert datetime to string so it can be displayed in the frontend #
         for i, t in enumerate(df.dtypes):
-            if t.name == 'datetime64[ns]':
-                df[df.columns[i]] = df[df.columns[i]
-                                       ].dt.strftime('%Y-%m-%d %H:%M:%S')
+            if t.name not in [CnextMimeType.FILE_PNG, CnextMimeType.FILE_JPG, CnextMimeType.FILE_JPEG, CnextMimeType.URL_PNG, CnextMimeType.URL_JPG, CnextMimeType.URL_JPEG]:
+                ## Convert everything else to string #
+                df[df.columns[i]] = df[df.columns[i]].apply(str)
 
         tableData['rows'] = df.values.tolist()
+
         # Modify data field of column with mime type of file/*. See note above
         #  We chose to do this outside of the dataframe, but it can also be done with a dataframe
         #  see https://stackoverflow.com/questions/41710501/is-there-a-way-to-have-a-dictionary-as-an-entry-of-a-pandas-dataframe-in-python ##
@@ -116,7 +132,7 @@ class MessageHandler(BaseMessageHandler):
         tableData['index'] = {}
         tableData['index']['name'] = df.index.name
         tableData['index']['data'] = []
-        if str(df.index.dtype) == 'datetime64[ns]':
+        if re.search(r'datetime', str(df.index.dtype)):
             [tableData['index']['data'].append(str(idx)) for idx in df.index]
         else:
             tableData['index']['data'] = df.index.tolist()
@@ -143,16 +159,26 @@ class MessageHandler(BaseMessageHandler):
             "%s.isna().sum()" % df_id, ExecutionMode.EVAL)
         describe = self.user_space.execute(
             "%s.describe(include='all')" % df_id, ExecutionMode.EVAL)
+        describe = self._convert_to_str_if_not_jsonable(describe)
+
         columns = {}
         MAX_UNIQUE_LENGTH = 1000
         for col_name, ctype in dtypes.items():
-            unique = self.user_space.execute(
-                "%s['%s'].unique().tolist()" % (df_id, col_name), ExecutionMode.EVAL)
+            if re.search(r'datetime', ctype.name):
+                ## the unique value of datetime is usually the same as the length so it is meaningless
+                ## also we have to convert it to string before sending back. So just don't do it now.
+                unique = []                
+            else:
+                unique = self.user_space.execute(
+                    "_pd.Series(%s['%s'].unique()).tolist()" % (df_id, col_name), ExecutionMode.EVAL)
+            
             # only send unique list that has length smaller than MAX_UNIQUE_LENGTH
             if len(unique) > MAX_UNIQUE_LENGTH:
                 unique = []
-            columns[col_name] = {'name': col_name, 'type': str(ctype.name), 'unique': unique,
-                                 'describe': describe[col_name].to_dict(), 'countna': countna[col_name].item()}
+            
+            columns[col_name] = {'name': col_name,
+                                 'type': str(ctype.name), 'unique': unique, 
+                                 'countna': countna[col_name].item(), 'describe': describe[col_name].to_dict()}
         output = {'df_id': df_id, 'shape': shape, 'columns': columns}
         return output
 
@@ -190,7 +216,8 @@ class MessageHandler(BaseMessageHandler):
                 message.error = error
 
             elif client_message.command_name == DFManagerCommand.get_table_data:
-                log.info('DFManagerCommand.get_table_data: %s' % result)
+                # log.info('DFManagerCommand.get_table_data: %s' % result)
+                log.info('DFManagerCommand.get_table_data')
                 message.content = result
                 message.type = ContentType.PANDAS_DATAFRAME
                 message.sub_type = SubContentType.NONE
@@ -202,22 +229,22 @@ class MessageHandler(BaseMessageHandler):
                 message.type = ContentType.DICT
                 message.sub_type = SubContentType.NONE
                 message.error = error
-            
+
             return message
-        
+
     def message_handler_callback(self, ipython_message, stream_type, client_message):
         try:
             # if self.request_metadata is not None:
             message = self._create_return_message(
                 ipython_message=ipython_message, stream_type=stream_type, client_message=client_message)
-            log.info('Message: %s' % message)
-            if message != None:                
+            if message != None:
+                log.info('Message: %s' % message.command_name)
                 self._send_to_node(message)
         except:
             trace = traceback.format_exc()
             log.info("Exception %s" % (trace))
             error_message = BaseMessageHandler._create_error_message(
-                client_message.webapp_endpoint, trace, {})
+                client_message.webapp_endpoint, trace, client_message.command_name, {})
             self._send_to_node(error_message)
 
     def handle_message(self, message):
@@ -259,5 +286,5 @@ class MessageHandler(BaseMessageHandler):
             trace = traceback.format_exc()
             log.error("%s" % (trace))
             error_message = MessageHandler._create_error_message(
-                message.webapp_endpoint, trace)
+                message.webapp_endpoint, trace, message.command_name)
             self._send_to_node(error_message)
