@@ -241,5 +241,5 @@ class MessageHandler(BaseMessageHandler):
             trace = traceback.format_exc()
             log.error("%s" % (trace))
             error_message = MessageHandler._create_error_message(
-                message.webapp_endpoint, trace)
+                message.webapp_endpoint, trace, message.command_name)
             self._send_to_node(error_message)
